==> refcomp-client-0.1-sources.jar: fr/inra/refcomp/client/constants/RefcompMessages.java <==
/*
 * #%L
 * Refcomp :: GWT client
 * 
 * $Id: RefcompMessages.java 79 2011-01-27 17:45:56Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-0.1/refcomp-client/src/main/java/fr/inra/refcomp/client/constants/RefcompMessages.java $
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.client.constants;

import com.google.gwt.i18n.client.Messages;

/**
 * User: couteau
 * Date: 31/12/10
 */
public interface RefcompMessages extends Messages {

    @Key("refcomp.searchResults.header.agentName")
    String agentName();

    @Key("refcomp.searchResults.header.skill")
    String skill();

    @Key("refcomp.searchResults.header.linkedSkill")
    String linkedSkill();

    @Key("refcomp.searchResults.header.frequency")
    String frequency();

    @Key("refcomp.searchResults.header.comment")
    String comment();

    @Key("refcomp.searchResults.header.unit")
    String unit();

    @Key("refcomp.searchResults.header.department")
    String department();

    @Key("refcomp.searchResults.header.cati")
    String cati();

    @Key("refcomp.constant.are.you.sure")
    String sure();

    @Key("refcomp.constant.edit")
    String edit();

    @Key("refcomp.constant.delete")
    String delete();

    @Key("refcomp.admin.skill.used")
    String skillUsed();

    @Key("refcomp.mySkills.path.button")
    String path();

    @Key("refcomp.mySkills.right.public")
    String publicRight();

    @Key("refcomp.mySkills.right.private")
    String privateRight();

    @Key("refcomp.searchResults.header.right")
    String right();

    @Key("refcomp.admin.skills.move.popup.errorMessage")
    String movePopUpErrorMessage();

    @Key("refcomp.admin.agent.password.mail.success")
    String passwordMailSent();

    @Key("refcomp.admin.agent.password.mail.error")
    String passwordMailError();
}

==> refcomp-client-1.0-sources.jar: fr/inra/refcomp/client/constants/RefcompMessages.java <==
/*
 * #%L
 * Refcomp :: GWT client
 * 
 * $Id: RefcompMessages.java 157 2011-04-14 15:46:48Z jcouteau $
 * $HeadURL: svn+ssh://jcouteau@scm.mulcyber.toulouse.inra.fr/svnroot/refcomp/tags/refcomp-1.0/refcomp-client/src/main/java/fr/inra/refcomp/client/constants/RefcompMessages.java $
 * %%
 * Copyright (C) 2010 - 2011 Inra
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.inra.refcomp.client.constants;

import com.google.gwt.i18n.client.Messages;

/**
 * User: couteau
 * Date: 31/12/10
 */
public interface RefcompMessages extends Messages {

    @Key("refcomp.searchResults.header.agentName")
    String agentName();

    @Key("refcomp.searchResults.header.rootSkill")
    String rootSkill();

    @Key("refcomp.searchResults.header.skill")
    String skill();

    @Key("refcomp.searchResults.header.linkedSkill")
    String linkedSkill();

    @Key("refcomp.searchResults.header.frequency")
    String frequency();

    @Key("refcomp.searchResults.header.comment")
    String comment();

    @Key("refcomp.searchResults.header.unit")
    String unit();

    @Key("refcomp.searchResults.header.department")
    String department();

    @Key("refcomp.searchResults.header.cati")
    String cati();

    @Key("refcomp.constant.are.you.sure")
    String sure();

    @Key("refcomp.constant.edit")
    String edit();

    @Key("refcomp.constant.modify")
    String modify();

    @Key("refcomp.constant.delete")
    String delete();

    @Key("refcomp.admin.skill.used")
    String skillUsed();

    @Key("refcomp.mySkills.path.button")
    String path();

    @Key("refcomp.mySkills.right.public")
    String publicRight();

    @Key("refcomp.mySkills.right.private")
    String privateRight();

    @Key("refcomp.searchResults.header.right")
    String right();

    @Key("refcomp.admin.skills.move.popup.errorMessage")
    String movePopUpErrorMessage();

    @Key("refcomp.admin.agent.password.mail.success")
    String passwordMailSent();

    @Key("refcomp.admin.agent.password.mail.error")
    String passwordMailError();

    @Key("refcomp.login.loginFailed")
    String loginFailed();

    @Key("refcomp.menu.login")
    String login();

    @Key("refcomp.menu.logout")
    String logout();

    @Key("refcomp.error.securityException")
    String securityException();

    @Key("refcomp.error.exception")
    String exception();

    @Key("refcomp.search.advancedSearchMask")
    String maskAvancedSearch();

    @Key("refcomp.search.advancedSearch")
    String avancedSearch();

    @Key("refcomp.loading")
    String loading();

    @Key("refcomp.admin.agent.jobType.reference.label")
    String jobTypeReference();

    @Key("refcomp.admin.user.wrong.password")
    String wrongPassword();

    @Key("refcomp.agent.mySkills.delete.tooltip")
    String deleteTooltip();

    @Key("refcomp.agent.mySkills.path.tooltip")
    String pathTooltip();
}
